@@ -234,7 +234,8 @@ class SelectPoller(object):
         """Process the self._timeouts event stack"""
         start_time = time.time()
         for timeout_id in self._timeouts.keys():
-            if self._timeouts[timeout_id]['timestamp'] <= start_time:
+            if (timeout_id in self._timeouts and
+                self._timeouts[timeout_id]['timestamp'] <= start_time):
                 handler = self._timeouts[timeout_id]['handler']
                 del self._timeouts[timeout_id]
                 handler()
